aboutsummaryrefslogtreecommitdiff
path: root/engines/draci/surface.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'engines/draci/surface.cpp')
-rw-r--r--engines/draci/surface.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/engines/draci/surface.cpp b/engines/draci/surface.cpp
index 1c7ecfb23b..532d87a19f 100644
--- a/engines/draci/surface.cpp
+++ b/engines/draci/surface.cpp
@@ -31,7 +31,7 @@ namespace Draci {
Surface::Surface(int width, int height) {
this->create(width, height, 1);
this->markClean();
- _transparentColour = kDefaultTransparent;
+ _transparentColor = kDefaultTransparent;
}
Surface::~Surface() {
@@ -80,12 +80,12 @@ void Surface::markClean() {
}
/**
* @brief Fills the surface with the specified colour
*/
-void Surface::fill(uint colour) {
+void Surface::fill(uint color) {
byte *ptr = (byte *)getBasePtr(0, 0);
- memset(ptr, colour, w * h);
+ memset(ptr, color, w * h);
}
/**
@@ -80,12 +80,12 @@ void Surface::markClean() {
}
/**
- * @brief Fills the surface with the specified colour
+ * @brief Fills the surface with the specified color
*/